WWTWindowsClient
================

.. currentmodule:: pywwt.windows.client

.. autoclass:: WWTWindowsClient
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~WWTWindowsClient.change_mode
      ~WWTWindowsClient.get_existing_layer
      ~WWTWindowsClient.get_frame_list
      ~WWTWindowsClient.get_layer_list
      ~WWTWindowsClient.get_state
      ~WWTWindowsClient.load
      ~WWTWindowsClient.move_view
      ~WWTWindowsClient.new_layer
      ~WWTWindowsClient.new_layer_group
      ~WWTWindowsClient.ui_settings

   .. rubric:: Methods Documentation

   .. automethod:: change_mode
   .. automethod:: get_existing_layer
   .. automethod:: get_frame_list
   .. automethod:: get_layer_list
   .. automethod:: get_state
   .. automethod:: load
   .. automethod:: move_view
   .. automethod:: new_layer
   .. automethod:: new_layer_group
   .. automethod:: ui_settings
